@@ -2,22 +2,15 @@
 Implements RegEx abstraction logic, for easy working with RegEx in Python.
 """
 __title__ = "remagic"
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __author__ = "ificiana"
 __license__ = "MIT License"
 __copyright__ = "Copyright 2022 ificiana"
 
 from .constants import Consts
-from .interface import (
-    create,
-    optional,
-    any_of,
-    char_in,
-    char_not_in,
-    exactly,
-    zero_or_more,
-    one_or_more,
-)
+from .interface import (after, any_of, before, char_in, char_not_in, create,
+                        exactly, not_after, not_before, one_or_more, optional,
+                        zero_or_more)
 
 CHAR = create(Consts.CHAR)
 WHITESPACE = create(Consts.WHITESPACE)
@@ -58,11 +51,15 @@ __all__ = [
     "WHITESPACE",
     "WORD",
     "WS",
+    "after",
     "any_of",
+    "before",
     "char_in",
     "char_not_in",
     "create",
     "exactly",
+    "not_after",
+    "not_before",
     "one_or_more",
     "optional",
     "zero_or_more",
