@@ -20,11 +20,15 @@ def optional(pattern):
 
 
 def zero_or_more(pattern, greedy=True):
-    return Pattern(pattern) * (0,) if greedy else optional(Pattern(pattern) * (0,))
+    if greedy:
+        return Pattern(pattern) * (0,)
+    return optional(Pattern(pattern) * (0,))
 
 
 def one_or_more(pattern, greedy=True):
-    return Pattern(pattern) * (1,) if greedy else optional(Pattern(pattern) * (1,))
+    if greedy:
+        return Pattern(pattern) * (1,)
+    return optional(Pattern(pattern) * (1,))
 
 
 def _char_set_items(iterable):
@@ -47,3 +51,27 @@ def char_not_in(iterable):
 
 def any_of(iterable):
     return exactly(f"{'|'.join(_alt_items(iterable))}")
+
+
+def before(pattern):
+    return rf"(?={Pattern(pattern)})"
+
+
+def not_before(pattern):
+    return rf"(?!={Pattern(pattern)})"
+
+
+def after(pattern):
+    return rf"(?<={Pattern(pattern)})"
+
+
+def not_after(pattern):
+    return rf"(?<!={Pattern(pattern)})"
+
+
+def ref(reference):
+    if isinstance(reference, int) and reference > 0:
+        return rf"\{reference}"
+    if isinstance(reference, str):
+        return rf"(?P={reference})"
+    return Pattern(reference)
